/*
  * Copyright (c) 2020 Graham Payne
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, 
 * and to permit persons to whom the Software is furnished to do so,
 * subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILIT, FITNESS
 * FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR
 * COPRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
 * IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
 * CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 
 
  This code uses bogde's excellent library:"https://github.com/bogde/HX711"

 The HX711 does one thing well: read load cells. The breakout board is compatible with any wheat-stone bridge
 based load cell which should allow a user to measure everything from a few grams to tens of tons.
 The HX711 board can be powered from 2.7V to 5V so the Arduino 5V power should be fine.

 This has been compiled and used on a Arduino Nano V3.0 sucessfully.

 Last edited on 27/07/2020 by Graham Payne
*/

#include "HX711.h"
#include <LiquidCrystal.h>

#define CLK1          14                                        // connections for the Weight sensors
#define DOUT1       15
#define CLK2          16
#define DOUT2       17

#define zero_factor_1           -694700                   // scale 1 offset. This value is obtained by using the Calibration sketch
#define zero_factor_2           -36740                     // scale 2 offset. This value is obtained by using the Calibration sketch
#define calibration_factor_1    -21650.0                    // Calibration factor, This value is obtained using the Calibration sketch
#define calibration_factor_2    -21200.0

LiquidCrystal lcd(8, 9, 4, 5, 6, 7);                        // RS, E, D4, D5, D6, D7. LCD 20 x 4 lines
HX711 scale1;                                                      // get an instance
HX711 scale2;                                                      // get another instance 

#define Keg1_Weight    4.33                                  // empty keg 1 weight     ************************TO  DO *********************************
#define Keg2_Weight    4.88                                  // empty keg 2 weight

void ScreenDraw() {                                             // headings
    lcd.clear();
    lcd.setCursor(1,0); lcd.print("GRAHAMS BEER KEGS");  
    lcd.setCursor(6,1); lcd.print("Litres");                  
    lcd.setCursor(0,2); lcd.print("KEG 1");              // 1 line per keg
    lcd.setCursor(0,3); lcd.print("KEG 2");
}

void setup() {
   lcd.begin(20,4);
   
   scale1.begin(DOUT1, CLK1);
   scale2.begin(DOUT2, CLK2);
   
   scale1.set_scale(calibration_factor_1);               // This value is obtained by using the Calibration sketch
   scale2.set_scale(calibration_factor_2);               // NO Tare in case of power failure or reset
   
   scale1.set_offset(zero_factor_1);
   scale2.set_offset(zero_factor_2);
   
   ScreenDraw();
//   scale1.tare();
//   scale2.tare();
}

void loop() {
    
    lcd.setCursor(6,2);                                              // col 6, leave room for minus sign
    lcd.print(scale1.get_units() - Keg1_Weight, 2);                           // get reading                
                                                                                // specific gravity of beer is close to 1, so kg = ltrs
                                                                                // you should Tare the empty keg with ball locks and tubes attached first
    delay(100);
    lcd.setCursor(6,3);                                              
    lcd.print(scale2.get_units() - Keg2_Weight, 2);

   delay(900);
}
